
*welcome to shinerainsevenlib*

Useful unadorned utilities for powerful Python programming.

[![License: LGPL v2.1](https://img.shields.io/badge/License-LGPL_v2.1-blue.svg)](https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html)

<br>
<br>

[Online documentation](https://moltenform.github.io/shinerainsevenlib/)

`python -m pip install shinerainsevenlib`

This project is useful for:

* functionality that isn't yet in the standard library
   * example: compressing and uncompressing .7z archives.
* functionality that is in the standard library, but isn't as intuitive
   * example: `files.run` is a convenient way to start a process.
* functionality for quickly writing one-off scripts
   * example: `files.writeAll` defaults to utf-8 and is quick to type and read.

